@@ -82,7 +82,29 @@ class AcquisitionParameter:
         tb.add_row("Filter Snapin","", self.filSnapin)
         tb.add_row("Multifilter","", str(self.multifilter))
         return tb
-        
+
+class SubFrame:
+    def __init__(self,proc) -> None:
+        self.firstLine = int(getValue(proc, 'img:first_line'))
+        self.firstSample = int(getValue(proc, 'img:first_sample'))
+        self.lines = int(getValue(proc, 'img:lines'))
+        self.samples = int(getValue(proc, 'img:samples'))
+        self.subFrameType = getValue(proc, 'img:subframe_type')
+    
+    def Show(self):
+        tb = Table(expand=False, show_header=False,
+                   show_lines=False, box=box.SIMPLE_HEAD,
+                   title="SubFrame Parameters", title_style="italic yellow")
+        tb.add_column(style='yellow', justify='left')
+        tb.add_column()
+        tb.add_column()
+        tb.add_row("First Sample", "", str(self.firstSample))
+        tb.add_row("First Line", "", str(self.firstLine))
+        tb.add_row("Sample", "", str(self.samples))
+        tb.add_row("Lines", "", str(self.lines))
+        tb.add_row("Subframe Type", "", self.subFrameType)
+        return tb
+      
 class OnBoardProcessing:
     
     def __init__(self,proc):
@@ -91,12 +113,13 @@ class OnBoardProcessing:
         self.badPixelMapName = getValue(
             proc, 'juice_janus:bad_pixel_map_name')
         self.badPixelCount = int(getValue(proc, 'juice_janus:bad_pixel_count'))
-        self.dnsuCorrection = int(getValue(proc, 'juice_janus:dsnu_correction'))
-        self.dnsuMapName = getValue(proc, 'juice_janus:dsnu_map_name')
+        self.fpnCorrection = int(getValue(proc, 'juice_janus:fpn_correction'))
+        self.fpnMapName = getValue(proc, 'juice_janus:fpn_map_name')
         self.spikeMaximumValue = int(
             getValue(proc, 'juice_janus:spike_maximum_value'))
         self.spikeDistance = int(getValue(proc, 'juice_janus:spike_distance'))
         self.spikeCount = int(getValue(proc, 'juice_janus:spike_count'))
+        self.spikeCorrection = int(getValue(proc, 'juice_janus:spike_correction'))
     
     def Show(self):
         tb = Table(expand=False, show_header=False,
@@ -109,12 +132,13 @@ class OnBoardProcessing:
         tb.add_row("Bad Pixel Map Name","", self.badPixelMapName)
         tb.add_row("Bad Pixel Count","", str(self.badPixelCount))
         tb.add_section()
-        tb.add_row("DSNU Correction", "", str(self.dnsuCorrection))
-        tb.add_row("DSNU Map Name","", self.dnsuMapName)
+        tb.add_row("FPN Correction", "", str(self.fpnCorrection))
+        tb.add_row("FPN Map Name","", self.fpnMapName)
         tb.add_section()
         tb.add_row("Spike Maximum Value", "", str(self.spikeMaximumValue))
         tb.add_row("Spike Distance","", str(self.spikeDistance))
         tb.add_row("Spike Distance","", str(self.spikeDistance))
+        tb.add_row("Spike Correction","", str(self.spikeCorrection))
         return tb
 
 class JanusReader:
@@ -132,7 +156,7 @@ class JanusReader:
             NOT_VALID_VICAR_FILE
                 The input file ``fileName`` is not ion VICAR format.
         """
-    __version__="0.1.2"
+    __version__="0.4.2"
     def __init__(self, fileName:Path, console:Console=None,debug:bool=False,vicar:bool=False):
         # Check if console exists, if not create one
         if console is None:
@@ -224,7 +248,7 @@ class JanusReader:
         self.Downsamplig=None
         self.Exposure = float(getValue(idObs, 'img:exposure_duration'))
         self.onBoardCompression=None
-        self.subFrame=None
+        self.subFrame = SubFrame(getElement(doc, 'img:Subframe'))
         self.Header=None
         # self.image=None
         flObs = getElement(doc, 'pds:File_Area_Observational')
@@ -238,9 +262,14 @@ class JanusReader:
             
         # if self.Format == "HALF":
         if self.level.lower()=='raw':
+            self.console.print(self.Offset)
+            self.console.print(self.Lines, self.Samples)
+            self.console.print(self.fileName.stat().st_size)
+            self.console.print(self.Lines*self.Samples*2+self.Offset)
             with open(self.fileName, 'rb') as f:
                 f.seek(self.Offset)
-                self.image=np.reshape(np.frombuffer(f.read(), dtype=np.uint16),(self.Lines,self.Samples))
+                self.image = np.reshape(np.frombuffer(f.read(
+                    self.Lines * self.Samples * 2), dtype=np.uint16), (self.Lines, self.Samples))
         else:
             with open(self.fileName, 'rb') as f:
                 self.image = np.reshape(np.frombuffer(
@@ -282,11 +311,10 @@ class JanusReader:
         tb.add_row("Downsampling","",str(self.Downsamplig))
         tb.add_row("Exposure","",str(self.Exposure))
         tb.add_row("On Board Compression","",str(self.onBoardCompression))
-        tb.add_row("SubFrame","",str(self.subFrame))
         tb.add_row("Header","", str(self.Header))
         # tb.add_row("Image","",str(self.image))
         if all:
-            col = Columns([tb, self.AcquisitionParameter.Show(), self.onBoardProcessing.Show()],expand=False)
+            col = Columns([tb, self.AcquisitionParameter.Show(), self.onBoardProcessing.Show(), self.subFrame.Show()],expand=False)
         else:
             col = tb
         self.console.print(Panel(col ,title=f"Label for {self.fileName.name}", border_style='yellow', expand=False))
